==> zio-aws-kendra_2.13-5.17.151.1-sources.jar: zio/aws/kendra/model/ConfluencePageToIndexFieldMapping.scala <==
package zio.aws.kendra.model
import zio.ZIO
import zio.aws.kendra.model.primitives.{
  IndexFieldName,
  DataSourceDateFieldFormat
}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ConfluencePageToIndexFieldMapping(
    dataSourceFieldName: Option[zio.aws.kendra.model.ConfluencePageFieldName] =
      None,
    dateFieldFormat: Option[DataSourceDateFieldFormat] = None,
    indexFieldName: Option[IndexFieldName] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kendra.model.ConfluencePageToIndexFieldMapping = {
    import ConfluencePageToIndexFieldMapping.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kendra.model.ConfluencePageToIndexFieldMapping
      .builder()
      .optionallyWith(dataSourceFieldName.map(value => value.unwrap))(
        _.dataSourceFieldName
      )
      .optionallyWith(
        dateFieldFormat.map(value =>
          DataSourceDateFieldFormat.unwrap(value): java.lang.String
        )
      )(_.dateFieldFormat)
      .optionallyWith(
        indexFieldName.map(value =>
          IndexFieldName.unwrap(value): java.lang.String
        )
      )(_.indexFieldName)
      .build()
  }
  def asReadOnly
      : zio.aws.kendra.model.ConfluencePageToIndexFieldMapping.ReadOnly =
    zio.aws.kendra.model.ConfluencePageToIndexFieldMapping.wrap(buildAwsValue())
}
object ConfluencePageToIndexFieldMapping {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kendra.model.ConfluencePageToIndexFieldMapping
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kendra.model.ConfluencePageToIndexFieldMapping =
      zio.aws.kendra.model.ConfluencePageToIndexFieldMapping(
        dataSourceFieldName.map(value => value),
        dateFieldFormat.map(value => value),
        indexFieldName.map(value => value)
      )
    def dataSourceFieldName
        : Option[zio.aws.kendra.model.ConfluencePageFieldName]
    def dateFieldFormat: Option[DataSourceDateFieldFormat]
    def indexFieldName: Option[IndexFieldName]
    def getDataSourceFieldName
        : ZIO[Any, AwsError, zio.aws.kendra.model.ConfluencePageFieldName] =
      AwsError.unwrapOptionField("dataSourceFieldName", dataSourceFieldName)
    def getDateFieldFormat: ZIO[Any, AwsError, DataSourceDateFieldFormat] =
      AwsError.unwrapOptionField("dateFieldFormat", dateFieldFormat)
    def getIndexFieldName: ZIO[Any, AwsError, IndexFieldName] =
      AwsError.unwrapOptionField("indexFieldName", indexFieldName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kendra.model.ConfluencePageToIndexFieldMapping
  ) extends zio.aws.kendra.model.ConfluencePageToIndexFieldMapping.ReadOnly {
    override val dataSourceFieldName
        : Option[zio.aws.kendra.model.ConfluencePageFieldName] = scala
      .Option(impl.dataSourceFieldName())
      .map(value => zio.aws.kendra.model.ConfluencePageFieldName.wrap(value))
    override val dateFieldFormat: Option[DataSourceDateFieldFormat] = scala
      .Option(impl.dateFieldFormat())
      .map(value =>
        zio.aws.kendra.model.primitives.DataSourceDateFieldFormat(value)
      )
    override val indexFieldName: Option[IndexFieldName] = scala
      .Option(impl.indexFieldName())
      .map(value => zio.aws.kendra.model.primitives.IndexFieldName(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.kendra.model.ConfluencePageToIndexFieldMapping
  ): zio.aws.kendra.model.ConfluencePageToIndexFieldMapping.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-kendra_2.13-5.19.8.4-sources.jar: zio/aws/kendra/model/ConfluencePageToIndexFieldMapping.scala <==
package zio.aws.kendra.model
import zio.ZIO
import zio.aws.kendra.model.primitives.{
  IndexFieldName,
  DataSourceDateFieldFormat
}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ConfluencePageToIndexFieldMapping(
    dataSourceFieldName: Optional[
      zio.aws.kendra.model.ConfluencePageFieldName
    ] = Optional.Absent,
    dateFieldFormat: Optional[DataSourceDateFieldFormat] = Optional.Absent,
    indexFieldName: Optional[IndexFieldName] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kendra.model.ConfluencePageToIndexFieldMapping = {
    import ConfluencePageToIndexFieldMapping.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kendra.model.ConfluencePageToIndexFieldMapping
      .builder()
      .optionallyWith(dataSourceFieldName.map(value => value.unwrap))(
        _.dataSourceFieldName
      )
      .optionallyWith(
        dateFieldFormat.map(value =>
          DataSourceDateFieldFormat.unwrap(value): java.lang.String
        )
      )(_.dateFieldFormat)
      .optionallyWith(
        indexFieldName.map(value =>
          IndexFieldName.unwrap(value): java.lang.String
        )
      )(_.indexFieldName)
      .build()
  }
  def asReadOnly
      : zio.aws.kendra.model.ConfluencePageToIndexFieldMapping.ReadOnly =
    zio.aws.kendra.model.ConfluencePageToIndexFieldMapping.wrap(buildAwsValue())
}
object ConfluencePageToIndexFieldMapping {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kendra.model.ConfluencePageToIndexFieldMapping
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kendra.model.ConfluencePageToIndexFieldMapping =
      zio.aws.kendra.model.ConfluencePageToIndexFieldMapping(
        dataSourceFieldName.map(value => value),
        dateFieldFormat.map(value => value),
        indexFieldName.map(value => value)
      )
    def dataSourceFieldName
        : Optional[zio.aws.kendra.model.ConfluencePageFieldName]
    def dateFieldFormat: Optional[DataSourceDateFieldFormat]
    def indexFieldName: Optional[IndexFieldName]
    def getDataSourceFieldName
        : ZIO[Any, AwsError, zio.aws.kendra.model.ConfluencePageFieldName] =
      AwsError.unwrapOptionField("dataSourceFieldName", dataSourceFieldName)
    def getDateFieldFormat: ZIO[Any, AwsError, DataSourceDateFieldFormat] =
      AwsError.unwrapOptionField("dateFieldFormat", dateFieldFormat)
    def getIndexFieldName: ZIO[Any, AwsError, IndexFieldName] =
      AwsError.unwrapOptionField("indexFieldName", indexFieldName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kendra.model.ConfluencePageToIndexFieldMapping
  ) extends zio.aws.kendra.model.ConfluencePageToIndexFieldMapping.ReadOnly {
    override val dataSourceFieldName
        : Optional[zio.aws.kendra.model.ConfluencePageFieldName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dataSourceFieldName())
        .map(value => zio.aws.kendra.model.ConfluencePageFieldName.wrap(value))
    override val dateFieldFormat: Optional[DataSourceDateFieldFormat] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dateFieldFormat())
        .map(value =>
          zio.aws.kendra.model.primitives.DataSourceDateFieldFormat(value)
        )
    override val indexFieldName: Optional[IndexFieldName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.indexFieldName())
        .map(value => zio.aws.kendra.model.primitives.IndexFieldName(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.kendra.model.ConfluencePageToIndexFieldMapping
  ): zio.aws.kendra.model.ConfluencePageToIndexFieldMapping.ReadOnly =
    new Wrapper(impl)
}
